@@ -309,3 +309,17 @@ class TestDap(object):
         assert 'Missing icon for assistant mod/foo/bar' in out.getvalue()
         assert 'Missing icon for assistant prep/foo/bar' in out.getvalue()
         assert 'Missing icon for assistant prep/foo/bar' in out.getvalue()
+
+    def test_dapi_check(self):
+        '''Dap that is already on dapi should produce a warning when network is True'''
+        out = StringIO()
+        os.environ['DAPI_FAKE_DATA'] = 'nonempty'
+        Dap('test/meta_only/foo-1.0.0.dap').check(output=out, network=True)
+        assert 'This dap name is already registered on Dapi' in out.getvalue()
+
+    def test_dapi_check_false(self):
+        '''Dap that is not already on dapi should not produce a warning when network is True'''
+        out = StringIO()
+        os.environ['DAPI_FAKE_DATA'] = ''
+        Dap('test/meta_only/foo-1.0.0.dap').check(output=out, network=True)
+        assert 'This dap name is already registered on Dapi' not in out.getvalue()
